@@ -10,7 +10,7 @@ except ImportError:
     # NOTE - could use subprocess to get from git?
     __rev__ = "local"
 
-__version__ = "0.15.4"
+__version__ = "0.15.5"
 
 _TEST_ENV = bool(os.environ.get("DP_TEST_ENV", ""))
 _IN_PYTEST = "pytest" in sys.modules
@@ -143,7 +143,7 @@ else:
 
 # TODO - do we want to init only in jupyter / interactive / etc.
 # only init fully in library-mode, as framework and app init explicitly
-if get_dp_mode() == DPMode.LIBRARY:
+if get_dp_mode() == DPMode.LIBRARY and not _IN_PYTEST:
     init()
 
 
