@@ -10,7 +10,7 @@ These objects are all available under the `datapane` module, via `import datapan
 
 The core document APIs, these are found in `datapane.client.api.report`, including,
 
-  - `datapane.client.api.report.core.Report`
+  - `datapane.client.api.report.core.App`
   - Layout Blocks
     - `datapane.client.api.report.blocks.Page`
     - `datapane.client.api.report.blocks.Group`
@@ -32,7 +32,7 @@ Additional API docs are found in `datapane.client.api.teams` that provide buildi
 
   - `datapane.client.api.teams.File`
   - `datapane.client.api.teams.Environment`
-  - `datapane.client.api.teams.App`
+  - `datapane.client.api.teams.LegacyApp`
   - `datapane.client.api.teams.Schedule`
 
 
@@ -49,6 +49,7 @@ import warnings
 from ..utils import IncompatibleVersionError
 from .common import HTTPError, Resource
 from .dp_object import DPObjectRef
+from .ipython_utils import cells_to_blocks
 from .report.blocks import (
     HTML,
     Attachment,
@@ -69,9 +70,20 @@ from .report.blocks import (
     Text,
     Toggle,
 )
-from .report.core import FontChoice, PageLayout, Report, ReportFormatting, ReportWidth, TextAlignment
+from .report.core import (
+    App,
+    AppFormatting,
+    AppWidth,
+    FontChoice,
+    PageLayout,
+    Report,
+    ReportFormatting,
+    ReportWidth,
+    TextAlignment,
+)
+from .report.processors import Processor, build, save_report, serve, upload
 from .runtime import Params, Result, _report, _reset_runtime, by_datapane
-from .teams import App, Environment, File, Run, Schedule
+from .teams import Environment, File, LegacyApp, Run, Schedule
 from .user import hello_world, login, logout, ping, template
 
 from ..config import init  # isort:skip  otherwise circular import issue
@@ -80,6 +92,9 @@ from . import builtins  # isort:skip
 __all__ = [
     "warnings",
     "init",
+    "App",
+    "AppFormatting",
+    "AppWidth",
     "IncompatibleVersionError",
     "builtins",
     "HTTPError",
@@ -95,9 +110,11 @@ __all__ = [
     "Empty",
     "Formula",
     "Group",
+    "LegacyApp",
     "Media",
     "Page",
     "Plot",
+    "Report",
     "Select",
     "SelectType",
     "Table",
@@ -105,7 +122,7 @@ __all__ = [
     "Toggle",
     "FontChoice",
     "PageLayout",
-    "Report",
+    "Processor",
     "ReportFormatting",
     "ReportWidth",
     "TextAlignment",
@@ -124,4 +141,9 @@ __all__ = [
     "logout",
     "ping",
     "template",
+    "upload",
+    "save_report",
+    "serve",
+    "build",
+    "cells_to_blocks",
 ]
