@@ -4,6 +4,8 @@ Datapane Reports Object
 Describes the `Report` object
 """
 
+from __future__ import annotations
+
 import dataclasses as dc
 import os
 import typing as t
@@ -138,8 +140,8 @@ class App(DPObjectRef):
         name: str,
         description: str = "",
         source_url: str = "",
-        publicly_visible: bool = False,
-        tags: t.List[str] = None,
+        publicly_visible: t.Optional[bool] = None,
+        tags: t.Optional[t.List[str]] = None,
         project: t.Optional[str] = None,
         open: bool = False,
         formatting: t.Optional[AppFormatting] = None,
@@ -166,6 +168,15 @@ class App(DPObjectRef):
 
         save_report(self, path, open, standalone, name, author, formatting, cdn_base)
 
+    @staticmethod
+    def from_notebook(opt_out: bool = True) -> App:
+        from ..ipython_utils import cells_to_blocks
+
+        blocks = cells_to_blocks(opt_out=opt_out)
+        app = App(blocks=blocks)
+
+        return app
+
     def stringify(
         self,
         standalone: bool = False,
