@@ -268,8 +268,8 @@ class Uploader(Processor):
         name: str,
         description: str = "",
         source_url: str = "",
-        publicly_visible: bool = False,
-        tags: t.List[str] = None,
+        publicly_visible: t.Optional[bool] = None,
+        tags: t.Optional[t.List[str]] = None,
         project: t.Optional[str] = None,
         open: bool = False,
         formatting: t.Optional[AppFormatting] = None,
@@ -282,9 +282,9 @@ class Uploader(Processor):
             name,
             description,
             source_url,
-            publicly_visible,
-            tags,
-            project,
+            publicly_visible=publicly_visible,
+            tags=tags,
+            project=project,
             formatting=formatting,
             overwrite=overwrite,
             **kwargs,
@@ -304,8 +304,8 @@ class Uploader(Processor):
         name: str,
         description: str = "",
         source_url: str = "",
-        publicly_visible: bool = False,
-        tags: t.List[str] = None,
+        publicly_visible: t.Optional[bool] = None,
+        tags: t.Optional[t.List[str]] = None,
         project: t.Optional[str] = None,
         formatting: t.Optional[AppFormatting] = None,
         overwrite: bool = False,
@@ -675,8 +675,8 @@ def upload(
     name: str,
     description: str = "",
     source_url: str = "",
-    publicly_visible: bool = False,
-    tags: t.List[str] = None,
+    publicly_visible: t.Optional[bool] = None,
+    tags: t.Optional[t.List[str]] = None,
     project: t.Optional[str] = None,
     open: bool = False,
     formatting: t.Optional[AppFormatting] = None,
