@@ -30,16 +30,11 @@ EXTRA_OUT: bool = False
 # TODO
 #  - add info subcommand
 #  - convert to use typer (https://github.com/tiangolo/typer) or autoclick
-def init(verbosity: int, config_env: str):
+def init(verbosity: int):
     """Init the cmd-line env"""
-    c.init(config_env=config_env)
+    c.init()
     _setup_dp_logging(verbosity=verbosity)
 
-    # config_f = c.load_from_envfile(config_env)
-    # _debug = debug if debug is not None else c.config.debug
-    # setup_logging(verbose_mode=_debug)
-    # log.debug(f"Loaded environment from {config_f}")
-
 
 @dc.dataclass(frozen=True)
 class DPContext:
@@ -48,8 +43,6 @@ class DPContext:
     easier to just use globals in general tho
     """
 
-    env: str
-
 
 @contextmanager
 def api_error_handler(err_msg: str):
@@ -104,15 +97,14 @@ def recursive_help(cmd, parent=None):  # noqa: ANN001
     count=True,
     help="Increase logging verbosity - can add multiple times",
 )
-@click.option("--env", default=c.DEFAULT_ENV, help="Alternate config environment to use.")
 @click.version_option(version=f"{__version__} ({__rev__})")
 @click.pass_context
-def cli(ctx: click.core.Context, verbose: int, env: str):
+def cli(ctx: click.core.Context, verbose: int):
     """Datapane CLI Tool"""
     global EXTRA_OUT
     EXTRA_OUT = verbose > 0
-    init(verbosity=verbose, config_env=env)
-    ctx.obj = DPContext(env=env)
+    init(verbosity=verbose)
+    ctx.obj = DPContext()
 
 
 # @cli.command()
@@ -128,7 +120,7 @@ def cli(ctx: click.core.Context, verbose: int, env: str):
 @click.pass_obj
 def login(obj: DPContext, token: str, server: str):
     """Login to a server with the given API token."""
-    api.login(token, server, env=obj.env)
+    api.login(token, server)
     # click.launch(f"{server}/settings/")
 
 
@@ -136,7 +128,7 @@ def login(obj: DPContext, token: str, server: str):
 @click.pass_obj
 def logout(obj: DPContext):
     """Logout from the server and reset the config file"""
-    api.logout(obj.env)
+    api.logout()
 
 
 @cli.command()
@@ -170,7 +162,6 @@ def template(url: URL, execute: bool):
 @cli.group()
 def file():
     """Commands to work with Files"""
-    pass
 
 
 @file.command()
@@ -216,7 +207,6 @@ def file_list():
 @cli.group()
 def app():
     """Commands to work with Apps"""
-    pass
 
 
 def write_templates(scaffold_name: str, context: SDict):
@@ -366,7 +356,6 @@ def run(
 @cli.group()
 def report():
     """Commands to work with Reports"""
-    pass
 
 
 # NOTE - CLI Report creation disabled for now until we have a replacement for Asset
@@ -432,7 +421,6 @@ def report_list():
 @cli.group()
 def environment():
     """Commands to work with Environments"""
-    pass
 
 
 @environment.command()
@@ -488,7 +476,6 @@ def delete(name: str, project: str):
 @cli.group()
 def schedule():
     """Commands to work with Schedules"""
-    pass
 
 
 @schedule.command()  # type: ignore[no-redef]
