@@ -27,7 +27,7 @@ ENVIRON_CONFIG = {
 RUN_NAME = "__datapane__"  # <datapane> ??
 
 
-def run(app: api.App, user_config: SDict, env: SSDict) -> SDict:
+def run(app: api.LegacyApp, user_config: SDict, env: SSDict) -> SDict:
     """Run a datapane python script/module"""
     api._reset_runtime(params=user_config)
     # use the app id for unique, isolated dir per app
@@ -125,7 +125,7 @@ def run_commands(cmds: List[str]) -> None:
             importlib.invalidate_caches()  # ensure new packages are detected
 
 
-def setup_script(s: api.App, env_dir: Path):
+def setup_script(s: api.LegacyApp, env_dir: Path):
     """Setup the script - unpack & install deps"""
     # TODO - add local cache check here
     if env_dir.exists():
